"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LogLevel = exports.NodejsFunction = void 0;
const aws_lambda_1 = require("aws-cdk-lib/aws-lambda");
const aws_s3_1 = require("aws-cdk-lib/aws-s3");
/**
 * NodejsFunction Mock
 *
 * Running NodejsFunction for CDK tests is extremely slow, as it requires Parcel Bundler to run inside docker. Instead
 * we use the Lambda Function class that it is based on, with code from a fake
 * S3 bucket.
 */
class NodejsFunction extends aws_lambda_1.Function {
    constructor(scope, id, props) {
        // Mock bucket
        const bucket = aws_s3_1.Bucket.fromBucketArn(scope, `${id}MockBucket`, "arn:aws:s3:::cdk-lambda-nodejs-mock-fake-bucket");
        // Create a Lambda Function without the real code generated using Parcel/Docker
        super(scope, id, {
            // Required values if not set for LambdaFunction
            runtime: aws_lambda_1.Runtime.NODEJS_12_X,
            handler: "index.handler",
            // Use other props
            ...props,
            // Set code with mock s3 location
            code: aws_lambda_1.Code.fromBucket(bucket, "cdk-lambda-nodejs-mock-fake-lambda.ts"),
        });
    }
}
exports.NodejsFunction = NodejsFunction;
/**
 * Export other Constructs/Classes from the @aws-cdk/aws-lambda-nodejs module without changes
 */
var aws_lambda_nodejs_1 = require("aws-cdk-lib/aws-lambda-nodejs");
Object.defineProperty(exports, "LogLevel", { enumerable: true, get: function () { return aws_lambda_nodejs_1.LogLevel; } });
